@@ -4,7 +4,7 @@ import pytest
 # A simplified demo
 def test_showver(dut):
     info = dut.eapi.sendcmd("show version")
-    logging.info(f"DUT model was: {info['modelName']}")
+    logging.info("DUT model was: %s" % info['modelName'])
 
 
 # A demo of an assertion, which we expect to fail
